==> moodle-2.1.3.tgz: moodle/lang/en/currencies.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'currencies', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   currencies
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['AED'] = 'United Arab Emirates Dirham';
$string['AFA'] = 'Afghanistan Afghani';
$string['ALL'] = 'Albanian Lek';
$string['ANG'] = 'Netherlands Antillian Guilder';
$string['AON'] = 'Angolan New Kwanza';
$string['ARA'] = 'Argentinian Nuevo Peso';
$string['AUD'] = 'Australian Dollar';
$string['AWG'] = 'Aruban Florin';
$string['BBD'] = 'Barbados Dollar';
$string['BDT'] = 'Bangladeshi Taka';
$string['BGL'] = 'Bulgarian Lev';
$string['BHD'] = 'Bahraini Dinar';
$string['BIF'] = 'Burundi Franc';
$string['BMD'] = 'Bermudian Dollar';
$string['BND'] = 'Brunei Dollar';
$string['BOB'] = 'Bolivian Boliviano';
$string['BRR'] = 'Brazilian Cruzeiro Real';
$string['BSD'] = 'Bahamian Dollar';
$string['BTN'] = 'Bhutan Ngultrum';
$string['BUK'] = 'Myanmar Kyat';
$string['BWP'] = 'Botswanian Pula';
$string['BZD'] = 'Belize Dollar';
$string['CAD'] = 'Canadian Dollar';
$string['CDZ'] = 'Zaire New Zaire';
$string['CLF'] = 'Chilean Unidades de Fomento';
$string['CLP'] = 'Chilean Peso';
$string['CNY'] = 'Yuan (Chinese) Renminbi';
$string['COP'] = 'Colombian Peso';
$string['CRC'] = 'Costa Rican Colon';
$string['CSD'] = 'Serbian Dinar';
$string['CUP'] = 'Cuban Peso';
$string['CVE'] = 'Escudo Caboverdiano';
$string['CYP'] = 'Cyprus Pound';
$string['CZK'] = 'Czech Koruna';
$string['DJF'] = 'Djibouti Franc';
$string['DKK'] = 'Danish Krone';
$string['DOP'] = 'Dominican Peso';
$string['DZD'] = 'Algerian Dinar';
$string['EGP'] = 'Egyptian Pound';
$string['ETB'] = 'Ethiopian Birr';
$string['EUR'] = 'Euro';
$string['FJD'] = 'Fiji Dollar';
$string['FKP'] = 'Falkland Islands Pound';
$string['GBP'] = 'British Pound';
$string['GHC'] = 'Ghanaian Cedi';
$string['GIP'] = 'Gibraltar Pound';
$string['GMD'] = 'Gambian Dalasi';
$string['GNF'] = 'Guinea Franc';
$string['GTQ'] = 'Guatemalan Quetzal';
$string['GWP'] = 'Guinea-Bissau Peso';
$string['GYD'] = 'Guyanan Dollar';
$string['HKD'] = 'Hong Kong Dollar';
$string['HNL'] = 'Honduran Lempira';
$string['HTG'] = 'Haitian Gourde';
$string['HUF'] = 'Hungarian Forint';
$string['CHF'] = 'Swiss Franc';
$string['IDR'] = 'Indonesian Rupiah';
$string['ILS'] = 'Israeli Shekel';
$string['INR'] = 'Indian Rupee';
$string['IQD'] = 'Iraqi Dinar';
$string['IRR'] = 'Iranian Rial';
$string['ISK'] = 'Iceland Krona';
$string['JMD'] = 'Jamaican Dollar';
$string['JOD'] = 'Jordanian Dinar';
$string['JPY'] = 'Japanese Yen';
$string['KES'] = 'Kenyan Schilling';
$string['KHR'] = 'Cambodian Riel';
$string['KMF'] = 'Comoros Franc';
$string['KPW'] = 'North Korean Won';
$string['KRW'] = 'South Korean Won';
$string['KWD'] = 'Kuwaiti Dinar';
$string['KYD'] = 'Cayman Islands Dollar';
$string['LAK'] = 'Lao Kip';
$string['LBP'] = 'Lebanese Pound';
$string['LKR'] = 'Sri Lanka Rupee';
$string['LRD'] = 'Liberian Dollar';
$string['LSL'] = 'Lesotho Loti';
$string['LYD'] = 'Libyan Dinar';
$string['MAD'] = 'Moroccan Dirham';
$string['MGF'] = 'Malagasy Franc';
$string['MNT'] = 'Mongolian Tugrik';
$string['MOP'] = 'Macau Pataca';
$string['MRO'] = 'Mauritanian Ouguiya';
$string['MTL'] = 'Maltese Lira';
$string['MUR'] = 'Mauritius Rupee';
$string['MVR'] = 'Maldive Rufiyaa';
$string['MWK'] = 'Malawi Kwacha';
$string['MXN'] = 'Mexican Peso';
$string['MYR'] = 'Malaysian Ringgit';
$string['MZM'] = 'Mozambique Metical';
$string['NGN'] = 'Nigerian Naira';
$string['NIO'] = 'Nicaraguan Cordoba';
$string['NOK'] = 'Norwegian Kroner';
$string['NPR'] = 'Nepalese Rupee';
$string['NZD'] = 'New Zealand Dollar';
$string['OMR'] = 'Omani Rial';
$string['PAB'] = 'Panamanian Balboa';
$string['PEN'] = 'Nuevo Sol';
$string['PGK'] = 'Papua New Guinea Kina';
$string['PHP'] = 'Philippine Peso';
$string['PKR'] = 'Pakistan Rupee';
$string['PLN'] = 'Polish New Zloty';
$string['PYG'] = 'Paraguay Guarani';
$string['QAR'] = 'Qatari Rial';
$string['ROL'] = 'Romanian Leu';
$string['RWF'] = 'Rwanda Franc';
$string['SAR'] = 'Saudi Arabian Riyal';
$string['SBD'] = 'Solomon Islands Dollar';
$string['SCR'] = 'Seychelles Rupee';
$string['SDP'] = 'Sudanese Pound';
$string['SEK'] = 'Swedish Krona';
$string['SGD'] = 'Singapore Dollar';
$string['SHP'] = 'St. Helena Pound';
$string['SKK'] = 'Slovak Koruna';
$string['SLL'] = 'Sierra Leone Leone';
$string['SOS'] = 'Somali Schilling';
$string['SRG'] = 'Suriname Guilder';
$string['STD'] = 'Sao Tome and Principe Dobra';
$string['SUR'] = 'USSR Rouble';
$string['SVC'] = 'El Salvador Colon';
$string['SYP'] = 'Syrian Potmd';
$string['SZL'] = 'Swaziland Lilangeni';
$string['THB'] = 'Thai Bhat';
$string['TND'] = 'Tunisian Dinar';
$string['TOP'] = 'Tongan Pa\'anga';
$string['TPE'] = 'East Timor Escudo';
$string['TRL'] = 'Turkish Lira';
$string['TTD'] = 'Trinidad and Tobago Dollar';
$string['TWD'] = 'Taiwan Dollar';
$string['TZS'] = 'Tanzanian Schilling';
$string['UGS'] = 'Uganda Shilling';
$string['USD'] = 'US Dollar';
$string['UYU'] = 'Uruguayan New Peso';
$string['VEB'] = 'Venezualan Bolivar';
$string['VND'] = 'Vietnamese Dong';
$string['VUV'] = 'Vanuatu Vatu';
$string['WST'] = 'Samoan Tala';
$string['YER'] = 'Yemeni Riyal';
$string['ZAR'] = 'South African Rand';
$string['ZMK'] = 'Zambian Kwacha';
$string['ZWD'] = 'Zimbabwe Dollar';

==> moodle-2.2.11.tgz: moodle/lang/en/currencies.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'currencies', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   currencies
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['AED'] = 'United Arab Emirates Dirham';
$string['AFN'] = 'Afghanistan Afghani';
$string['ALL'] = 'Albanian Lek';
$string['AMD'] = 'Armenian Dram';
$string['ANG'] = 'Netherlands Antillean Guilder';
$string['AOA'] = 'Angolan Kwanza';
$string['ARS'] = 'Argentine Peso';
$string['AUD'] = 'Australian Dollar';
$string['AWG'] = 'Aruban Florin';
$string['AZN'] = 'Azerbaijanian Manat';
$string['BAM'] = 'Bosnia and Herzegovina Convertible Mark';
$string['BBD'] = 'Barbados Dollar';
$string['BDT'] = 'Bangladeshi Taka';
$string['BGN'] = 'Bulgarian Lev';
$string['BHD'] = 'Bahraini Dinar';
$string['BIF'] = 'Burundi Franc';
$string['BMD'] = 'Bermudian Dollar';
$string['BND'] = 'Brunei Dollar';
$string['BOB'] = 'Bolivian Boliviano';
$string['BRL'] = 'Brazilian Real';
$string['BSD'] = 'Bahamian Dollar';
$string['BTN'] = 'Bhutanese Ngultrum';
$string['BWP'] = 'Botswana Pula';
$string['BYR'] = 'Belarusian Ruble';
$string['BZD'] = 'Belize Dollar';
$string['CAD'] = 'Canadian Dollar';
$string['CDF'] = 'Congolese Franc';
$string['CHF'] = 'Swiss Franc';
$string['CLF'] = 'Chilean Unidades de Fomento';
$string['CLP'] = 'Chilean Peso';
$string['CNY'] = 'Chinese Yuan (Renminbi)';
$string['COP'] = 'Colombian Peso';
$string['CRC'] = 'Costa Rican Colon';
$string['CUC'] = 'Cuban Convertible Peso';
$string['CUP'] = 'Cuban Peso';
$string['CVE'] = 'Cape Verde Escudo';
$string['CZK'] = 'Czech Koruna';
$string['DJF'] = 'Djibouti Franc';
$string['DKK'] = 'Danish Krone';
$string['DOP'] = 'Dominican Peso';
$string['DZD'] = 'Algerian Dinar';
$string['EGP'] = 'Egyptian Pound';
$string['ERN'] = 'Eritrean Nakfa';
$string['ETB'] = 'Ethiopian Birr';
$string['EUR'] = 'Euro';
$string['FJD'] = 'Fiji Dollar';
$string['FKP'] = 'Falkland Islands Pound';
$string['GBP'] = 'British Pound Sterling';
$string['GEL'] = 'Georgian Lari';
$string['GHS'] = 'Ghanaian Cedi';
$string['GIP'] = 'Gibraltar Pound';
$string['GMD'] = 'Gambian Dalasi';
$string['GNF'] = 'Guinea Franc';
$string['GTQ'] = 'Guatemalan Quetzal';
$string['GYD'] = 'Guyanese Dollar';
$string['HKD'] = 'Hong Kong Dollar';
$string['HNL'] = 'Honduran Lempira';
$string['HRK'] = 'Croatian Kuna';
$string['HTG'] = 'Haitian Gourde';
$string['HUF'] = 'Hungarian Forint';
$string['IDR'] = 'Indonesian Rupiah';
$string['ILS'] = 'Israeli Sheqel';
$string['INR'] = 'Indian Rupee';
$string['IQD'] = 'Iraqi Dinar';
$string['IRR'] = 'Iranian Rial';
$string['ISK'] = 'Iceland Krona';
$string['JMD'] = 'Jamaican Dollar';
$string['JOD'] = 'Jordanian Dinar';
$string['JPY'] = 'Japanese Yen';
$string['KES'] = 'Kenyan Shilling';
$string['KGS'] = 'Kyrgyzstani Som';
$string['KHR'] = 'Cambodian Riel';
$string['KMF'] = 'Comoros Franc';
$string['KPW'] = 'North Korean Won';
$string['KRW'] = 'South Korean Won';
$string['KWD'] = 'Kuwaiti Dinar';
$string['KYD'] = 'Cayman Islands Dollar';
$string['KZT'] = 'Kazakhstani Tenge';
$string['LAK'] = 'Lao Kip';
$string['LBP'] = 'Lebanese Pound';
$string['LKR'] = 'Sri Lanka Rupee';
$string['LRD'] = 'Liberian Dollar';
$string['LSL'] = 'Lesotho Loti';
$string['LTL'] = 'Lithuanian Litas';
$string['LVL'] = 'Latvian Lats';
$string['LYD'] = 'Libyan Dinar';
$string['MAD'] = 'Moroccan Dirham';
$string['MDL'] = 'Moldovan Leu';
$string['MGA'] = 'Malagasy Ariary';
$string['MKD'] = 'Makedonian Denar';
$string['MMK'] = 'Myanmar (Burmese) Kyat';
$string['MNT'] = 'Mongolian Tugrik';
$string['MOP'] = 'Macau Pataca';
$string['MRO'] = 'Mauritanian Ouguiya';
$string['MUR'] = 'Mauritius Rupee';
$string['MVR'] = 'Maldivian Rufiyaa';
$string['MWK'] = 'Malawi Kwacha';
$string['MXN'] = 'Mexican Peso';
$string['MYR'] = 'Malaysian Ringgit';
$string['MZN'] = 'Mozambican Metical';
$string['NAD'] = 'Namibian Dollar';
$string['NGN'] = 'Nigerian Naira';
$string['NIO'] = 'Nicaraguan Cordoba Oro';
$string['NOK'] = 'Norwegian Krone';
$string['NPR'] = 'Nepalese Rupee';
$string['NZD'] = 'New Zealand Dollar';
$string['OMR'] = 'Omani Rial';
$string['PAB'] = 'Panamanian Balboa';
$string['PEN'] = 'Peruvian Nuevo Sol';
$string['PGK'] = 'Papua New Guinea Kina';
$string['PHP'] = 'Philippine Peso';
$string['PKR'] = 'Pakistan Rupee';
$string['PLN'] = 'Polish Zloty';
$string['PYG'] = 'Paraguayan Guarani';
$string['QAR'] = 'Qatari Rial';
$string['RON'] = 'Romanian Leu';
$string['RSD'] = 'Serbian Dinar';
$string['RUB'] = 'Russian Ruble';
$string['RWF'] = 'Rwanda Franc';
$string['SAR'] = 'Saudi Arabian Riyal';
$string['SBD'] = 'Solomon Islands Dollar';
$string['SCR'] = 'Seychelles Rupee';
$string['SDG'] = 'Sudanese Pound';
$string['SEK'] = 'Swedish Krona';
$string['SGD'] = 'Singapore Dollar';
$string['SHP'] = 'St. Helena Pound';
$string['SLL'] = 'Sierra Leonean Leone';
$string['SOS'] = 'Somali Shilling';
$string['SRD'] = 'Surinamese Dollar';
$string['SSP'] = 'South Sudanese Pound';
$string['STD'] = 'Sao Tome and Principe Dobra';
$string['SVC'] = 'El Salvador Colon';
$string['SYP'] = 'Syrian Pound';
$string['SZL'] = 'Swazi Lilangeni';
$string['THB'] = 'Thai Baht';
$string['TJS'] = 'Tajikistani Somoni';
$string['TMT'] = 'Turkmenistani Manat';
$string['TND'] = 'Tunisian Dinar';
$string['TOP'] = 'Tongan Pa\'anga';
$string['TRY'] = 'Turkish Lira';
$string['TTD'] = 'Trinidad and Tobago Dollar';
$string['TWD'] = 'Taiwan Dollar';
$string['TZS'] = 'Tanzanian Shilling';
$string['UAH'] = 'Ukrainian Hryvnia';
$string['UGX'] = 'Ugandan Shilling';
$string['USD'] = 'US Dollar';
$string['UYU'] = 'Uruguayan Peso';
$string['UZS'] = 'Uzbekistani Sum';
$string['VEF'] = 'Venezuelan Bolivar Fuerte';
$string['VND'] = 'Vietnamese Dong';
$string['VUV'] = 'Vanuatu Vatu';
$string['WST'] = 'Samoan Tala';
$string['XAF'] = 'CFA Franc BEAC';
$string['XCD'] = 'East Caribbean Dollar';
$string['XOF'] = 'CFA Franc BCEAO';
$string['XPF'] = 'CFP Franc';
$string['YER'] = 'Yemeni Rial';
$string['ZAR'] = 'South African Rand';
$string['ZMK'] = 'Zambian Kwacha';
$string['ZWL'] = 'Zimbabwe Dollar';
